Crate opensearch_query_builder

Crate opensearch_query_builder 

This crate provides a simple way to dynamically build OpenSearch queries in a type-safe manner.

Structs

BoolQuery
Bool Query
BoolQueryBuilder
Builder pattern for BoolQuery that allows dynamic updates.
CardinalityAggregation
Cardinality Aggregation
Collapse
Collapse
DecayFunction
Decay function configuration
FieldSort
Field Sort
FieldValueFactor
Field value factor configuration
FunctionScoreQuery
Function Score Query
FunctionScoreQueryBuilder
Builder pattern for FunctionScoreQuery that allows dynamic updates.
Highlight
Highlight
HighlightField
HighlightField
MatchPhrasePrefixQuery
Match Phrase Prefix Query
MatchPhraseQuery
Match Phrase Query
MatchQuery
Match Query
RandomScore
Random score configuration
RangeQuery
Range Query
RangeQueryBuilder
Builder pattern for RangeQuery that allows dynamic updates.
RegexpQuery
Regexp Query
ScoreFunction
A single scoring function with optional filter and weight
ScoreWithOrderSort
Score sort with order
Script
Script
ScriptScore
Script score configuration
ScriptSort
Script Sort
SearchRequest
Struct representing a search request.
SearchRequestBuilder
Builder pattern for SearchRequest that allows dynamic updates. Unlike the fluent methods on SearchRequest, this builder uses mutable methods so you can dynamically add fields over time before calling build().
TermQuery
Term Query
TermsAggregation
Terms Aggregation
TermsQuery
Terms Query
WildcardQuery
Wildcard Query

Enums

AggregationType
Aggregation Type
BoostMode
Boost mode
Lang
Script Lang
QueryType
Enum representing the different types of queries that can be used in a search request.
RegexpQueryFlags
Enum representing the different flags that can be used with a RegexpQuery
ScoreFunctionType
Enum representing different scoring functions
ScoreMode
Score mode
ScriptSortType
Script Sort Type
SortMode
Sort Mode
SortOrder
Sort Order
SortType
Sort Type

Traits

ToOpenSearchJson
Trait for converting a Rust struct to an OpenSearch JSON object.