pub enum RegexpQueryFlags {
All,
Anystring,
Complement,
Empty,
Intersection,
Interval,
None,
}Expand description
Enum representing the different flags that can be used with a RegexpQuery
Variants
All
Enables all optional features (default behavior)
Anystring
Allows @ to match any string
Complement
Matches the complement of the language described by the regex
Empty
Allows matching empty strings
Intersection
Enables intersection of multiple patterns
Interval
Enables interval arithmetic on character classes
None
Disables all optional features (default behavior)
Implementations