This crate provides a simple way to dynamically build OpenSearch queries in a type-safe manner.
Structs
- Bool
Query - Bool Query
- Bool
Query Builder - Builder pattern for BoolQuery that allows dynamic updates.
- Cardinality
Aggregation - Cardinality Aggregation
- Collapse
- Collapse
- Decay
Function - Decay function configuration
- Field
Sort - Field Sort
- Field
Value Factor - Field value factor configuration
- Function
Score Query - Function Score Query
- Function
Score Query Builder - Builder pattern for FunctionScoreQuery that allows dynamic updates.
- Highlight
- Highlight
- Highlight
Field - HighlightField
- Match
Phrase Prefix Query - Match Phrase Prefix Query
- Match
Phrase Query - Match Phrase Query
- Match
Query - Match Query
- Random
Score - Random score configuration
- Range
Query - Range Query
- Range
Query Builder - Builder pattern for RangeQuery that allows dynamic updates.
- Regexp
Query - Regexp Query
- Score
Function - A single scoring function with optional filter and weight
- Score
With Order Sort - Score sort with order
- Script
- Script
- Script
Score - Script score configuration
- Script
Sort - Script Sort
- Search
Request - Struct representing a search request.
- Search
Request Builder - Builder pattern for SearchRequest that allows dynamic updates. Unlike the fluent methods on SearchRequest, this builder uses mutable methods so you can dynamically add fields over time before calling build().
- Term
Query - Term Query
- Terms
Aggregation - Terms Aggregation
- Terms
Query - Terms Query
- Wildcard
Query - Wildcard Query
Enums
- Aggregation
Type - Aggregation Type
- Boost
Mode - Boost mode
- Lang
- Script Lang
- Query
Type - Enum representing the different types of queries that can be used in a search request.
- Regexp
Query Flags - Enum representing the different flags that can be used with a RegexpQuery
- Score
Function Type - Enum representing different scoring functions
- Score
Mode - Score mode
- Script
Sort Type - Script Sort Type
- Sort
Mode - Sort Mode
- Sort
Order - Sort Order
- Sort
Type - Sort Type
Traits
- ToOpen
Search Json - Trait for converting a Rust struct to an OpenSearch JSON object.